import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import { message, Form, Switch, Input, Modal } from 'antd';
import Uploader from '../../../components/Uploader';
import { Codes, statuses } from '../../../utils/config';

const FormItem = Form.Item

@Form.create()
export default class ModalForm extends PureComponent {
  static propTypes = {
    item: PropTypes.object,
    form: PropTypes.object,
    onOk: PropTypes.func,
  };
  
  state = { file: '' };

  componentWillReceiveProps(nextProps) {
    this.setState({ file: nextProps.item.url });
  }

  handleSingleUpload = (file) => {
    if (file) {
      message.success('图片上传成功!');
    }
    this.setState({ file });
  }

  handleOk = () => {
    const { form: { validateFields, resetFields }, onOk } = this.props;
    validateFields((errors) => {
      if (errors) { return; }
      const data = {
        ...getFieldsValue(),
      };
      item.id ? data.id = item.id : null;
      onOk(data);
      resetFields();
    });
  }

  render() {
    const { item = {}, form: { getFieldDecorator }, signature, modalType, ...modalProps } = this.props;
    const { file } = this.state;
    const modalOpts = { ...modalProps, onOk: this.handleOk };

    const formItemLayout = {
      labelCol: {
        span: 7,
      },
      wrapperCol: {
        span: 14,
      },
    };

    return (
      <Modal key={item.id} {...modalOpts}>
        <Form layout="horizontal">
          <FormItem label="图片编号：" hasFeedback {...formItemLayout}>
            {getFieldDecorator('code', {
              rules: [{ required: true, type: 'string', message: "此项为必填项!" }],
              initialValue: item.code,
            })(<Input />)}
          </FormItem>
          <FormItem label="图片名称：" hasFeedback {...formItemLayout}>
            {getFieldDecorator('name', {
              rules: [{ required: true, type: 'string', message: "此项为必填项!" }],
              initialValue: item.name,
            })(<Input />)}
          </FormItem>
          <FormItem label="单图上传" {...formItemLayout}>
            <Uploader
              accept="image"
              files={file}
              signature={signature}
              onUpload={::this.handleSingleUpload}
            />
          </FormItem>
          <FormItem label="使用状态：" {...formItemLayout}>
            {getFieldDecorator('status', {
              valuePropsName: 'checked',
          })(<Switch defaultChecked={item.status || Codes.CODE_NORMAL === Codes.CODE_NORMAL ? true : false} checkedChildren="使用中" unCheckedChildren="已删除" />)}
          </FormItem>
        </Form>
      </Modal>
    );
  }
}
